*************
Basic editing
*************

Required and desired fields
===========================

Read and Update Mode
====================
Items can be opened in read and update mode. In read mode all fields are
rendererd as readonly fields and no editing is possible regardless of your
current permissions. In updated mode the fields are usual editable but further
constraint in the form of the items can turn single fields into readonly mode.

.. _usage_changepermission:
Changing Item permissions
=========================

Special form elements
=====================
